@@ -34,8 +34,6 @@ and :func:`exec_with_return` are provided. the helper function :func:`try_eval`
 """
 import ast
 import datetime
-import importlib.abc
-import importlib.util
 import logging
 import logging.config as logging_config
 import os
@@ -44,20 +42,19 @@ import threading
 import unicodedata
 import weakref
 
-from importlib.machinery import ModuleSpec
 from inspect import getinnerframes, getouterframes, getsourcefile
 from string import ascii_letters, digits
-from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, Type, Union
+from typing import Any, Callable, Dict, Generator, List, Optional, Tuple, Type
 from _ast import stmt
 
-from ae.base import DATE_ISO, DATE_TIME_ISO, UNSET, UnsetType, norm_name, norm_path, project_main_file  # type: ignore
+from ae.base import DATE_ISO, DATE_TIME_ISO, UNSET, import_module, norm_name, norm_path             # type: ignore
 
 
-__version__ = '0.2.12'
+__version__ = '0.3.13'
 
 
 # suppress unused import err (needed e.g. for unpickling of dates via try_eval() and for include them into base_globals)
-_d = (DATE_ISO, DATE_TIME_ISO,
+_d = (os, DATE_ISO, DATE_TIME_ISO,
       ascii_letters, digits, datetime, logging, logging_config, norm_name, norm_path, threading, unicodedata, weakref)
 
 SKIPPED_MODULES = ('ae.base', 'ae.paths', 'ae.inspector', 'ae.core', 'ae.console', 'ae.gui_app',
@@ -134,39 +131,20 @@ def full_stack_trace(ex: Exception) -> str:
     return ret
 
 
-def module_attr(import_name: str, attr_name: str = "", project_path: Union[str, UnsetType] = "") -> Optional[Any]:
+def module_attr(import_name: str, attr_name: str = "") -> Optional[Any]:
     """ determine dynamically a reference to a module or to any attribute (variable/func/class) declared in the module.
 
-    :param import_name:         name of the distribution/module/package to load/import. for modules not in the cwd
-                                and not already imported, pass also the :paramref:`~module_attr.project_path` argument.
-    :param attr_name:           name of the attribute declared within the module. if not passed or passed an empty
-                                string then a reference to module instance will be returned.
-    :param project_path:        optional path where the project folder of the searched main module is situated (only
-                                needed if the module is not not in the current working directory and not in `sys.path`/
-                                `sys.modules). to skip the module file search, and directly use sys.modules[import_name]
-                                pass :data:`~ae.base.UNSET`.
-    :return:                    module instance or module attribute value (UNSET if module/attribute doesn't exist).
+    :param import_name:         import-/dot-name of the distribution/module/package to load/import.
+    :param attr_name:           name of the attribute declared within the module. do not specify or pass an empty
+                                string to get/return a reference to the imported module instance.
+    :return:                    module instance or module attribute value
+                                or None if module not found
+                                or UNSET if module attribute doesn't exist.
 
-    -- hint:: a previously not imported module will *not* be added to `sys.modules` by this function.
+    .. note:: a previously not imported module will *not* be added to `sys.modules` by this function.
 
     """
-    mod_file = "" if project_path is UNSET else project_main_file(import_name, project_path=project_path)
-    mod_ref = UNSET
-
-    if os.path.isfile(mod_file):
-        spec = importlib.util.spec_from_file_location(import_name, mod_file)
-        # workaround for mypy >= V 0.901: added assert and import (from importlib.machinery import ModuleSpec)
-        assert isinstance(spec, ModuleSpec)
-        mod_ref = importlib.util.module_from_spec(spec)
-
-        # mypy: had to add import (import importlib.abc) and assert and then also noinspection for PyCharm
-        assert isinstance(spec.loader, importlib.abc.Loader)
-        # noinspection PyUnresolvedReferences
-        spec.loader.exec_module(mod_ref)
-
-    elif import_name in sys.modules:
-        mod_ref = sys.modules[import_name]
-
+    mod_ref = sys.modules.get(import_name, None) or import_module(import_name)
     return getattr(mod_ref, attr_name, UNSET) if mod_ref and attr_name else mod_ref
 
 
@@ -175,7 +153,7 @@ def module_file_path(local_object: Optional[Callable] = None) -> str:
 
     :param local_object:        optional local module, class, method, function, traceback, frame, or code object of the
                                 calling module (passing `lambda: 0` also works). omit to use instead the `__file__`
-                                module variable (which will not work if the module is frozen (by py2exe/PyInstaller).
+                                module variable (which will not work if the module is frozen by py2exe/PyInstaller).
     :return:                    module path (inclusive module file name) or empty string if path not found/determinable.
     """
     if local_object:
@@ -194,7 +172,7 @@ def module_name(*skip_modules: str, depth: int = 0) -> Optional[str]:
     :param skip_modules:        module names to skip (def=this ae.core module).
     :param depth:               the calling level from which on to search. the default value 0 refers the frame and
                                 the module of the caller of this function.
-                                pass 1 or a even higher value if you want to get the module name of a function/method
+                                pass 1 or an even higher value if you want to get the module name of a function/method
                                 in a deeper level in the call stack.
     :return:                    the module name of the call stack level specified by :paramref:`~module_name.depth`.
     """
@@ -229,7 +207,7 @@ def stack_var(name: str, *skip_modules: str, scope: str = '', depth: int = 1) ->
                                 'globals' to only check for global variables (ignoring locals). the default value (an
                                 empty string) will not restrict the scope, returning either a local or global value.
     :param depth:               the calling level from which on to search. the default value (1) refers the next
-                                deeper stack frame, which is the caller of the function). pass 2 or a even higher
+                                deeper stack frame, which is the caller of the function. pass 2 or an even higher
                                 value if you want to start the variable search from a deeper level in the call stack.
     :return:                    the variable value of a deeper level within the call stack or UNSET if the variable was
                                 not found.
@@ -288,7 +266,7 @@ def try_call(callee: Callable, *args, ignored_exceptions: Tuple[Type[Exception],
     :param args:                function arguments tuple.
     :param ignored_exceptions:  tuple of ignored exceptions.
     :param kwargs:              function keyword arguments dict.
-    :return:                    function return value or UNSET if a ignored exception got thrown.
+    :return:                    function return value or UNSET if an ignored exception got thrown.
     """
     ret = UNSET
     try:  # catch type conversion errors, e.g. for datetime.date(None) while bool(None) works (->False)
@@ -330,7 +308,7 @@ def try_exec(code_block: str, ignored_exceptions: Tuple[Type[Exception], ...] =
     :param ignored_exceptions:  tuple of ignored exceptions.
     :param glo_vars:            optional globals() available in the code execution.
     :param loc_vars:            optional locals() available in the code execution.
-    :return:                    function return value or UNSET if a ignored exception got thrown.
+    :return:                    function return value or UNSET if an ignored exception got thrown.
     """
     ret = UNSET
     try:
